==> Couchbase-Java-Client-3.2.7.zip: com/couchbase/client/core/cnc/events/request/RequestRetryScheduledEvent.java <==
/*
 * Copyright (c) 2018 Couchbase, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.couchbase.client.core.cnc.events.request;

import com.couchbase.client.core.cnc.AbstractEvent;
import com.couchbase.client.core.msg.RequestContext;
import com.couchbase.client.core.retry.RetryReason;

import java.time.Duration;

public class RequestRetryScheduledEvent extends AbstractEvent {

  private final Class<?> request;
  private final RetryReason retryReason;

  public RequestRetryScheduledEvent(Duration duration, RequestContext context, Class<?> request, final RetryReason reason) {
    super(Severity.DEBUG, Category.REQUEST, duration, context);
    this.request = request;
    this.retryReason = reason;
  }

  public Class<?> requestClass() {
    return request;
  }

  public RetryReason retryReason() {
    return retryReason;
  }

  @Override
  public String description() {
    return "Request " + request.getSimpleName() + " retry scheduled per RetryStrategy (Reason: " + retryReason + ")";
  }
}

==> Couchbase-Java-Client-3.10.0.zip: com/couchbase/client/core/cnc/events/request/RequestRetryScheduledEvent.java <==
/*
 * Copyright (c) 2018 Couchbase, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.couchbase.client.core.cnc.events.request;

import com.couchbase.client.core.cnc.AbstractEvent;
import com.couchbase.client.core.cnc.Context;
import com.couchbase.client.core.retry.RetryReason;

import java.time.Duration;

public class RequestRetryScheduledEvent extends AbstractEvent {

  private final Class<?> request;
  private final RetryReason retryReason;

  public RequestRetryScheduledEvent(Duration duration, Context context, Class<?> request, final RetryReason reason) {
    super(Severity.DEBUG, Category.REQUEST, duration, context);
    this.request = request;
    this.retryReason = reason;
  }

  public Class<?> requestClass() {
    return request;
  }

  public RetryReason retryReason() {
    return retryReason;
  }

  @Override
  public String description() {
    return "Request " + request.getSimpleName() + " retry scheduled per RetryStrategy (Reason: " + retryReason + ")";
  }
}
